/**************************************************************
  (C) 1997 by Achim Kaiser

  You may distribute under the terms of the GNU General Public
  License as specified in the COPYING file.
**************************************************************/

#ifndef ICONMANAGER_H
#define ICONMANAGER_H

#include <X11/Xlib.h>
#include <X11/Xutil.h>
#include <X11/cursorfont.h>

#define TYPE      0
#define NAME      1
#define EXTENSION 2
#define DATEASC   3
#define DATEDESC  4
#define SIZEASC   5
#define SIZEDESC  6
#define ARRANGE   7


struct item *GetDirentryFromWindow(Window win);

void SetPositionOnLastIcon();

void MakeWindowIcons();

void MakeWindowTree();

Window LowerIcons();

struct item *SortIcons(int type,struct item *top);

void SortIconsTop(int type);

void PlaceIcons();

int UpdateDetailView(Window win);

void UpdateWindow();

void UpdateIcons(int fast);

int HandleTheEvent(XEvent evnt);

void UnsetMarks();

void SetAllMarks();

void PlusTree(struct item *fileitem);

void MinusTree(struct item *fileitem);

void ArrangeTree();

#endif

